# dwh-oppfolging
Public repository for the development of the dwh-oppfolging python package.

## Installation
`pip install dwh-oppfolging`

## Inquiries
Questions pertaining to the codebase may be opened as GitHub issues using the `question` label.

### For NAV employees
Internal inquiries may be posted to #dv-oppfølging.
